==> maradns-1.1.16.tar.bz2: maradns-1.1.16/tcp/getzone_es.h <==
#define L_FATAL_COMMENT "# Error fatal: "
#define L_TIMEOUT "Tiempo de espera agotado"
#define L_USAGE "Uso: getzone zone_name zone_server_IP"
#define L_VALID_IP "Usa una IP válida para el servidor de zonas, por favor"
#define L_NO_SOCK "Imposible crear un socket TCP"
#define L_NO_CONNECT "Imposible conectar con el servidor de zonas"
#define L_NO_SEND "Imposible crear el objeto para mandar"
#define L_NO_HEADER "Imposible crear la cabecera DNS"
#define L_NO_ZSTRING "Imposible crear el objeto para la zona"
#define L_QSTR2JS_ERROR "qstr2js"
#define L_APPEND_Z "Imposible añadir la cadena de la zona a el objeto de la zona"
#define L_APPEND_D "imposible añadir el punto al final de la cadena de la zona"
#define L_INVALID_NAME "Nombre de zona no válido"
#define L_APPEND_ZS "Imposible añadir la cadena de la zona para enviarla"
#define L_ADD_QT "No se pudo añadir el tipo de consulta al enviar"
#define L_ADD_QC "No se pudo añadir la clase de la consulta al enviar"
#define L_SEND_2BYTE "No se pudo enviar la cabecera de 2 bytes al servidor de zonas"
#define L_SEND_QUERY "No se pudo enviar la consulta al servidor de zonas"
#define L_C_RRNAME "No se pudo crear rr.name"
#define L_MNAME "No se pudo crear soa.mname"
#define L_RNAME "No se pudo crear soa.rname"
#define L_NOT_MANLY "La respuesta del servidor no es suficientemente grande para la cabecera"
#define L_NO_GET "No hubo memoria para la cadena"
#define L_NO_EXPAND "No hubo memoria para alargar la cadena"
#define L_SERVER "No se recibió el paquete del servidor"
#define L_DECOMPRESS "Hubo un error fatal en la descompresión"
#define L_RHEADER "No se pudo leer la cabecera del servidor"
#define L_FORMAT "Error de formato"
#define L_SERVER_FAIL "Fallo del servidor"
#define L_NAME "Error en el nombre"
#define L_NOTIMPL "No implementado"
#define L_REFUSE "Rechazado"
#define L_RCODE "Rcode > 5"
#define L_DLABEL "dlabel no válido en la cuestión"
#define L_READ_RR_H "Error fatal ejecutandog read_rr_h"
#define L_GET_S "No se puede coger la cadena"
#define L_GET_COPY "Error fatal copiando el nombre a get"
#define L_BALIWICK "# Disabled out-of-baliwick record follows"
#define L_HASH "# "
#define L_CGET "No se puede hacer get string"
#define L_RDDATA "Hubo un problema al obtener rddata"
#define L_TRANS "Problema traducieno el nombre del registro A"
#define LF "\n"
#define L_HNAME "Problema Hname "
#define L_ZERO "No se admiten nombres de longitud 0!"

==> maradns_2.0.09.orig.tar.bz2: maradns-2.0.09/tcp/getzone_es.h <==
#define L_FATAL_COMMENT "# Error fatal: "
#define L_TIMEOUT "Tiempo de espera agotado"
#define L_USAGE "Uso: getzone zone_name zone_server_IP"
#define L_USAGE_FETCH "Uso: fetchzone zone_name zone_server_IP"
#define L_VALID_IP "Usa una IP vlida para el servidor de zonas, por favor"
#define L_NO_SOCK "Imposible crear un socket TCP"
#define L_NO_CONNECT "Imposible conectar con el servidor de zonas"
#define L_NO_SEND "Imposible crear el objeto para mandar"
#define L_NO_HEADER "Imposible crear la cabecera DNS"
#define L_NO_ZSTRING "Imposible crear el objeto para la zona"
#define L_QSTR2JS_ERROR "qstr2js"
#define L_APPEND_Z "Imposible aadir la cadena de la zona a el objeto de la zona"
#define L_APPEND_D "imposible aadir el punto al final de la cadena de la zona"
#define L_INVALID_NAME "Nombre de zona no vlido"
#define L_APPEND_ZS "Imposible aadir la cadena de la zona para enviarla"
#define L_ADD_QT "No se pudo aadir el tipo de consulta al enviar"
#define L_ADD_QC "No se pudo aadir la clase de la consulta al enviar"
#define L_SEND_2BYTE "No se pudo enviar la cabecera de 2 bytes al servidor de zonas"
#define L_SEND_QUERY "No se pudo enviar la consulta al servidor de zonas"
#define L_C_RRNAME "No se pudo crear rr.name"
#define L_MNAME "No se pudo crear soa.mname"
#define L_RNAME "No se pudo crear soa.rname"
#define L_NOT_MANLY "La respuesta del servidor no es suficientemente grande para la cabecera"
#define L_NO_GET "No hubo memoria para la cadena"
#define L_NO_EXPAND "No hubo memoria para alargar la cadena"
#define L_SERVER "No se recibi el paquete del servidor"
#define L_DECOMPRESS "Hubo un error fatal en la descompresin"
#define L_RHEADER "No se pudo leer la cabecera del servidor"
#define L_FORMAT "Error de formato"
#define L_SERVER_FAIL "Fallo del servidor"
#define L_NAME "Error en el nombre"
#define L_NOTIMPL "No implementado"
#define L_REFUSE "Rechazado"
#define L_RCODE "Rcode > 5"
#define L_DLABEL "dlabel no vlido en la cuestin"
#define L_READ_RR_H "Error fatal ejecutandog read_rr_h"
#define L_GET_S "No se puede coger la cadena"
#define L_GET_COPY "Error fatal copiando el nombre a get"
#define L_BALIWICK "# Disabled out-of-baliwick record follows"
#define L_HASH "# "
#define L_CGET "No se puede hacer get string"
#define L_RDDATA "Hubo un problema al obtener rddata"
#define L_TRANS "Problema traducieno el nombre del registro A"
#define LF "\n"
#define L_HNAME "Problema Hname "
#define L_ZERO "No se admiten nombres de longitud 0!"
